==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorPushTransactionRejectedAllOfProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionRejectedAllOfProfile
 */
@JsonPropertyOrder({ UserFactorPushTransactionRejectedAllOfProfile.JSON_PROPERTY_CREDENTIAL_ID })
@JsonTypeName("UserFactorPushTransactionRejected_allOf_profile")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorPushTransactionRejectedAllOfProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREDENTIAL_ID = "credentialId";
    private String credentialId;

    public UserFactorPushTransactionRejectedAllOfProfile() {
    }

    public UserFactorPushTransactionRejectedAllOfProfile credentialId(String credentialId) {

        this.credentialId = credentialId;
        return this;
    }

    /**
     * ID for the Factor credential
     *
     * @return credentialId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "dade.murphy@example.com", value = "ID for the Factor credential")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCredentialId() {
        return credentialId;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredentialId(String credentialId) {
        this.credentialId = credentialId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionRejectedAllOfProfile userFactorPushTransactionRejectedAllOfProfile = (UserFactorPushTransactionRejectedAllOfProfile) o;
        return Objects.equals(this.credentialId, userFactorPushTransactionRejectedAllOfProfile.credentialId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(credentialId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionRejectedAllOfProfile {\n");
        sb.append("    credentialId: ").append(toIndentedString(credentialId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorPushTransactionRejectedAllOfProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionRejectedAllOfProfile
 */
@JsonPropertyOrder({ UserFactorPushTransactionRejectedAllOfProfile.JSON_PROPERTY_CREDENTIAL_ID })
@JsonTypeName("UserFactorPushTransactionRejected_allOf_profile")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorPushTransactionRejectedAllOfProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREDENTIAL_ID = "credentialId";
    private String credentialId;

    public UserFactorPushTransactionRejectedAllOfProfile() {
    }

    public UserFactorPushTransactionRejectedAllOfProfile credentialId(String credentialId) {

        this.credentialId = credentialId;
        return this;
    }

    /**
     * ID for the Factor credential
     *
     * @return credentialId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "dade.murphy@example.com", value = "ID for the Factor credential")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCredentialId() {
        return credentialId;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredentialId(String credentialId) {
        this.credentialId = credentialId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionRejectedAllOfProfile userFactorPushTransactionRejectedAllOfProfile = (UserFactorPushTransactionRejectedAllOfProfile) o;
        return Objects.equals(this.credentialId, userFactorPushTransactionRejectedAllOfProfile.credentialId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(credentialId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionRejectedAllOfProfile {\n");
        sb.append("    credentialId: ").append(toIndentedString(credentialId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
